==> git-projects-0.2.1.tar.gz: git-projects-0.2.1/git_projects/command.py <==
from argparse import ArgumentParser
from subprocess import (Popen, PIPE)

from git_projects.shortcut import ShortcutHolder


PROJECT_PREFIX = '@'
SHORTCUT_PREFIX = '--'


class GitError(Exception):
    pass


def parse_args():
    """
    Build and parse command args.
    """
    parser = ArgumentParser(description='git-projects')
    parser.add_argument(PROJECT_PREFIX, nargs='+', help='project name')
    for name in ShortcutHolder.REGISTRY:
        shortcut = ShortcutHolder.REGISTRY[name]
        option = SHORTCUT_PREFIX + shortcut.option
        description = shortcut.description
        parser.add_argument(option, action='store_true', help=description)
    return parser.parse_known_args()


def parse_command():
    """
    Properly parsing command line arguments.
    """
    args, ignored_args = parse_args()
    shortcut_args = args.__dict__.copy()
    del shortcut_args[PROJECT_PREFIX]
    args = args.__dict__.get(PROJECT_PREFIX)

    projects = list()
    git_args = list()

    for arg in args:
        if str.startswith(arg, PROJECT_PREFIX):
            projects.append(arg)
        else:
            git_args.append(arg)

    for i in range(len(projects)):
        projects[i] = projects[i][1:]

    return projects, git_args + ignored_args, shortcut_args


def git(target, *args):
    """
    Git command opener wrapper.
    """
    cmd = ['git'] + list(args)
    popen = Popen(cmd, close_fds=True, cwd=target,
                  stdin=PIPE, stdout=PIPE, stderr=PIPE)
    out, err = popen.communicate()
    if popen.returncode != 0:
        raise GitError(err.decode('utf-8'))
    return out.decode('utf-8')

==> git-projects-0.3.4.tar.gz: git-projects-0.3.4/git_projects/command.py <==
import re
from argparse import ArgumentParser
from subprocess import (Popen, PIPE)

from git_projects.shortcut import ShortcutHolder


PROJECT_PREFIX = '@'
SHORTCUT_PREFIX = '--'


class GitError(Exception):
    pass


def parse_args():
    """
    Build and parse command args.
    """
    parser = ArgumentParser(description='git-projects')
    parser.add_argument(PROJECT_PREFIX, nargs='+', help='project name')
    for name in ShortcutHolder.REGISTRY:
        shortcut = ShortcutHolder.REGISTRY[name]
        option = SHORTCUT_PREFIX + shortcut.option
        description = shortcut.description
        parser.add_argument(option, action='store_true', help=description)
    return parser.parse_known_args()


def parse_command():
    """
    Properly parsing command line arguments.
    """
    args, ignored_args = parse_args()
    shortcut_args = args.__dict__.copy()
    del shortcut_args[PROJECT_PREFIX]
    args = args.__dict__.get(PROJECT_PREFIX)

    projects = list()
    git_args = list()

    for arg in args:
        if str.startswith(arg, PROJECT_PREFIX):
            projects.append(arg)
        else:
            git_args.append(arg)

    for i in range(len(projects)):
        projects[i] = projects[i][1:]

    return projects, git_args + ignored_args, shortcut_args


def git(target, *args):
    """
    Git command opener wrapper.
    """
    cmd = list()
    for arg in args:
        regex = re.compile(r'`(?P<subargs>.+)`')
        match = re.search(regex, arg)
        if not match:
            cmd.append(arg)
            continue

        subargs = match.group('subargs').split(' ')
        output = _exec(target, subargs)
        output = re.sub(regex, output, arg)
        output = output.replace('\n', '')

        cmd.append(output)

    cmd = ['git'] + list(cmd)
    return _exec(target, cmd)


def _exec(target, *args):
    """
    Open a command as a subprocess.
    """
    popen = Popen(*args, close_fds=True, cwd=target,
                  stdin=PIPE, stdout=PIPE, stderr=PIPE)
    out, err = popen.communicate()
    if popen.returncode != 0:
        raise GitError(err.decode('utf-8'))
    return out.decode('utf-8')
